# Aquarius Documentation for Operators

This documentation is for someone who just wants to _run_ Aquarius, such as someone operating a data marketplace in the Ocean Network.

_For now_, if you're developing a marketplace, you'll want to run Aquarius and several other components, and the easiest way to do all that is to use our Docker Compose setup. For details, see [the docs page about setting up a marketplace](https://docs.oceanprotocol.com/setup/marketplace/).
